"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCredentialQueryParser = exports.getJsonClaimsQueriesForClaimSet = exports.getMdocClaimsQueriesForClaimSet = exports.getJsonClaimsParser = exports.getNamespacesParser = void 0;
const v = __importStar(require("valibot"));
const e_dcql_js_1 = require("../dcql-error/e-dcql.js");
const m_dcql_claims_query_js_1 = require("../dcql-query/m-dcql-claims-query.js");
const u_dcql_js_1 = require("../u-dcql.js");
const getClaimParser = (input) => {
    const { value, values } = input;
    if (value) {
        return v.literal(value);
    }
    if (values) {
        return v.union(values.map(val => v.literal(val)));
    }
    return m_dcql_claims_query_js_1.DcqlClaimsQuery.vValue;
};
const getNamespacesParser = (claimsQueries) => {
    const claimsForNamespace = {};
    for (const claimQuery of claimsQueries) {
        if (claimsForNamespace[claimQuery.namespace]) {
            claimsForNamespace[claimQuery.namespace]?.push({ ...claimQuery });
        }
        else {
            claimsForNamespace[claimQuery.namespace] = [{ ...claimQuery }];
        }
    }
    const parsersForNamespaces = Object.entries(claimsForNamespace).map(([namespace, claims]) => {
        const claimParsers = Object.fromEntries(claims.map(claim => [claim.claim_name, getClaimParser(claim)]));
        return [namespace, v.object(claimParsers)];
    });
    return v.object(Object.fromEntries(parsersForNamespaces));
};
exports.getNamespacesParser = getNamespacesParser;
const getClaimQueryParser = (claimQuery, ctx) => {
    const { index, presentation } = ctx;
    const pathElement = claimQuery.path[index];
    const isLast = index === claimQuery.path.length - 1;
    const vClaimParser = claimQuery.values ? getClaimParser(claimQuery) : u_dcql_js_1.vJson;
    if (typeof pathElement === 'number') {
        const elementParser = isLast
            ? vClaimParser
            : getClaimQueryParser(claimQuery, { ...ctx, index: index + 1 });
        if (presentation) {
            // We allow both the concrete value and an array of one value
            return v.union([
                v.pipe(v.array(u_dcql_js_1.vJson), v.length(1), v.transform(input => input[0]), elementParser),
                elementParser,
            ]);
        }
        return v.pipe(v.array(u_dcql_js_1.vJson), v.transform(input => input[pathElement]), elementParser);
    }
    else if (typeof pathElement === 'string') {
        return v.object({
            [pathElement]: isLast
                ? vClaimParser
                : getClaimQueryParser(claimQuery, { ...ctx, index: index + 1 }),
        });
    }
    else {
        return isLast
            ? v.array(vClaimParser)
            : v.array(getClaimQueryParser(claimQuery, { ...ctx, index: index + 1 }));
    }
};
const getJsonClaimsParser = (claimsQueries, ctx) => {
    const claimParser = v.intersect(claimsQueries.map(claimQuery => getClaimQueryParser(claimQuery, {
        ...ctx,
        index: 0,
    })));
    return claimParser;
};
exports.getJsonClaimsParser = getJsonClaimsParser;
const getMdocClaimsQueriesForClaimSet = (claimsQueries, claimSet) => {
    return claimSet.map(credential_id => {
        const query = claimsQueries.find(query => query.id === credential_id);
        if (!query) {
            throw new e_dcql_js_1.DcqlInvalidClaimsQueryIdError({
                message: `Claims-query with id '${credential_id}' not found.`,
            });
        }
        return query;
    });
};
exports.getMdocClaimsQueriesForClaimSet = getMdocClaimsQueriesForClaimSet;
const getJsonClaimsQueriesForClaimSet = (claimsQueries, claimSet) => {
    return claimSet.map(credential_id => {
        const query = claimsQueries.find(query => query.id === credential_id);
        if (!query) {
            throw new e_dcql_js_1.DcqlInvalidClaimsQueryIdError({
                message: `Claims-query with id '${credential_id}' not found.`,
            });
        }
        return query;
    });
};
exports.getJsonClaimsQueriesForClaimSet = getJsonClaimsQueriesForClaimSet;
const getMdocParser = (credentialQuery, ctx) => {
    const { claimSet } = ctx;
    const vDoctype = credentialQuery.meta?.doctype_value
        ? v.literal(credentialQuery.meta.doctype_value)
        : v.string();
    const claimSetQueries = credentialQuery.claims && claimSet
        ? (0, exports.getMdocClaimsQueriesForClaimSet)(credentialQuery.claims, claimSet)
        : credentialQuery.claims;
    const credentialParser = v.object({
        credential_format: v.literal('mso_mdoc'),
        doctype: vDoctype,
        namespaces: claimSetQueries
            ? (0, exports.getNamespacesParser)(claimSetQueries)
            : v.record(v.string(), v.record(v.string(), v.unknown())),
    });
    return credentialParser;
};
const getW3cVcSdJwtVcParser = (credentialQuery, ctx) => {
    const { claimSet } = ctx;
    const claimSetQueries = credentialQuery.claims && claimSet
        ? (0, exports.getJsonClaimsQueriesForClaimSet)(credentialQuery.claims, claimSet)
        : credentialQuery.claims;
    if (credentialQuery.format === 'vc+sd-jwt') {
        return v.object({
            credential_format: v.literal('vc+sd-jwt'),
            vct: credentialQuery.meta?.vct_values
                ? v.picklist(credentialQuery.meta.vct_values)
                : v.string(),
            claims: claimSetQueries
                ? (0, exports.getJsonClaimsParser)(claimSetQueries, ctx)
                : u_dcql_js_1.vJsonRecord,
        });
    }
    else {
        const credentialParser = v.object({
            credential_format: v.picklist(['jwt_vc_json', 'jwt_vc_json-ld']),
            claims: claimSetQueries
                ? (0, exports.getJsonClaimsParser)(claimSetQueries, ctx)
                : u_dcql_js_1.vJsonRecord,
        });
        return credentialParser;
    }
};
const getCredentialQueryParser = (credentialQuery, ctx) => {
    if (credentialQuery.claim_sets && !ctx.claimSet) {
        throw new e_dcql_js_1.DcqlMissingClaimSetParseError({
            message: `credentialQuery specifies claim_sets but no claim_set for parsing is provided.`,
        });
    }
    if (credentialQuery.format === 'mso_mdoc') {
        return getMdocParser(credentialQuery, ctx);
    }
    else {
        return getW3cVcSdJwtVcParser(credentialQuery, ctx);
    }
};
exports.getCredentialQueryParser = getCredentialQueryParser;
//# sourceMappingURL=dcql-claims-query-result.js.map