"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DcqlPresentationResult = void 0;
const v = __importStar(require("valibot"));
const e_dcql_js_1 = require("../dcql-error/e-dcql.js");
const dcql_credential_query_result_js_1 = require("../dcql-parser/dcql-credential-query-result.js");
const m_dcql_query_result_js_1 = require("../dcql-query-result/m-dcql-query-result.js");
const u_dcql_js_1 = require("../u-dcql.js");
var DcqlPresentationResult;
(function (DcqlPresentationResult) {
    DcqlPresentationResult.vModel = v.object({
        ...v.omit(m_dcql_query_result_js_1.DcqlQueryResult.vModel, ['credential_matches']).entries,
        invalid_matches: v.union([
            v.record(v.pipe(v.string(), v.regex(u_dcql_js_1.idRegex)), v.object({
                ...v.omit(u_dcql_js_1.vCredentialParseFailure, ['input_credential_index'])
                    .entries,
                presentation_id: v.pipe(v.string(), v.regex(u_dcql_js_1.idRegex)),
            })),
            v.undefined(),
        ]),
        valid_matches: v.record(v.pipe(v.string(), v.regex(u_dcql_js_1.idRegex)), v.object({
            ...v.omit(m_dcql_query_result_js_1.DcqlQueryResult.vModel.entries.credential_matches.value.options[0], ['all', 'issues', 'input_credential_index']).entries,
            presentation_id: v.pipe(v.string(), v.regex(u_dcql_js_1.idRegex)),
        })),
    });
    DcqlPresentationResult.parse = (input) => {
        return v.parse(DcqlPresentationResult.vModel, input);
    };
    /**
     * Query if the presentation record can be satisfied by the provided presentations
     * considering the dcql query
     *
     * @param dcqlQuery
     * @param dcqlPresentation
     */
    DcqlPresentationResult.fromDcqlPresentation = (dcqlPresentation, ctx) => {
        const { dcqlQuery } = ctx;
        const presentationQueriesResults = Object.fromEntries(Object.entries(dcqlPresentation).map(([queryId, presentation]) => {
            const credentialQuery = dcqlQuery.credentials.find(c => c.id === queryId);
            if (!credentialQuery) {
                throw new e_dcql_js_1.DcqlPresentationResultError({
                    message: `Query ${queryId} not found in the dcql query. Cannot validate presentation.`,
                });
            }
            return [
                queryId,
                (0, dcql_credential_query_result_js_1.runCredentialQuery)(credentialQuery, {
                    presentation: true,
                    credentials: [presentation],
                }),
            ];
        }));
        let invalidMatches = undefined;
        const validMatches = {};
        for (const [queryId, presentationQueryResult] of Object.entries(presentationQueriesResults)) {
            for (const presentationQueryResultForClaimSet of presentationQueryResult) {
                const result = 
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                presentationQueryResultForClaimSet[0];
                if (result.success) {
                    const { issues, input_credential_index, ...rest } = result;
                    validMatches[queryId] = { ...rest, presentation_id: queryId };
                }
                else {
                    if (!invalidMatches)
                        invalidMatches = {};
                    const { input_credential_index, ...rest } = result;
                    invalidMatches[queryId] = {
                        ...rest,
                        presentation_id: queryId,
                    };
                }
            }
        }
        const credentialSetResults = dcqlQuery.credential_sets?.map(set => {
            const matchingOptions = set.options.filter(option => option.every(credentialQueryId => validMatches[credentialQueryId]?.success));
            return {
                ...set,
                matching_options: matchingOptions.length > 0
                    ? matchingOptions
                    : undefined,
            };
        });
        const dqclQueryMatched = credentialSetResults
            ? credentialSetResults.every(set => !set.required || set.matching_options)
            : !invalidMatches;
        return {
            ...dcqlQuery,
            canBeSatisfied: dqclQueryMatched,
            valid_matches: validMatches,
            invalid_matches: invalidMatches,
            credential_sets: credentialSetResults,
        };
    };
    DcqlPresentationResult.validate = (dcqlQueryResult) => {
        if (!dcqlQueryResult.canBeSatisfied) {
            throw new e_dcql_js_1.DcqlInvalidPresentationRecordError({
                message: 'Invalid Presentation record',
                cause: dcqlQueryResult,
            });
        }
        return dcqlQueryResult;
    };
})(DcqlPresentationResult || (exports.DcqlPresentationResult = DcqlPresentationResult = {}));
//# sourceMappingURL=m-dcql-presentation-result.js.map