"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runDcqlQuery = void 0;
const dcql_credential_query_result_js_1 = require("../dcql-parser/dcql-credential-query-result.js");
const runDcqlQuery = (dcqlQuery, ctx) => {
    const credentialQueriesResults = Object.fromEntries(dcqlQuery.credentials.map(credentialQuery => [
        credentialQuery.id,
        (0, dcql_credential_query_result_js_1.runCredentialQuery)(credentialQuery, ctx),
    ]));
    const credentialMatches = Object.fromEntries(Object.entries(credentialQueriesResults).map(([key, credentialQueryResult]) => {
        // Find the best match for each credential query
        let bestMatch = undefined;
        for (const credentialParseResult of credentialQueryResult) {
            const bestMatchForCredential = credentialParseResult.find(result => result?.success == true);
            if (!bestMatch && bestMatchForCredential) {
                const { issues, ...matchWithoutIssues } = bestMatchForCredential;
                bestMatch = matchWithoutIssues;
                continue;
            }
            if (bestMatchForCredential &&
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                bestMatchForCredential.claim_set_index <
                    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion, @typescript-eslint/no-non-null-asserted-optional-chain
                    bestMatch?.claim_set_index) {
                const { issues, ...matchWithoutIssues } = bestMatchForCredential;
                bestMatch = matchWithoutIssues;
            }
        }
        return [
            key,
            bestMatch
                ? { ...bestMatch, all: credentialQueryResult }
                : { success: false, all: credentialQueryResult },
        ];
    }));
    const credentialSetResults = dcqlQuery.credential_sets?.map(set => {
        const matchingOptions = set.options.filter(option => option.every(credentialQueryId => credentialMatches[credentialQueryId]?.success));
        return {
            ...set,
            matching_options: matchingOptions.length > 0
                ? matchingOptions
                : undefined,
        };
    });
    const dqclQueryMatched = credentialSetResults
        ? credentialSetResults.every(set => !set.required || set.matching_options)
        : Object.values(credentialMatches).every(query => query.success);
    return {
        ...dcqlQuery,
        canBeSatisfied: dqclQueryMatched,
        credential_matches: credentialMatches,
        credential_sets: credentialSetResults,
    };
};
exports.runDcqlQuery = runDcqlQuery;
//# sourceMappingURL=run-dcql-query.js.map