"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DcqlCredentialQuery = void 0;
const v = __importStar(require("valibot"));
const e_dcql_js_1 = require("../dcql-error/e-dcql.js");
const u_dcql_js_1 = require("../u-dcql.js");
const m_dcql_claims_query_js_1 = require("./m-dcql-claims-query.js");
/**
 * A Credential Query is an object representing a request for a presentation of one Credential.
 */
var DcqlCredentialQuery;
(function (DcqlCredentialQuery) {
    const vBase = v.object({
        id: v.pipe(v.string(), v.regex(u_dcql_js_1.idRegex), v.description(`REQUIRED. A string identifying the Credential in the response and, if provided, the constraints in 'credential_sets'.`)),
        claim_sets: v.pipe(v.optional(v.pipe(v.array(v.array(v.pipe(v.string(), v.regex(u_dcql_js_1.idRegex)))), (0, u_dcql_js_1.vNonEmptyArray)())), v.description(`OPTIONAL. A non-empty array containing arrays of identifiers for elements in 'claims' that specifies which combinations of 'claims' for the Credential are requested.`)),
    });
    DcqlCredentialQuery.vMdoc = v.object({
        ...vBase.entries,
        format: v.pipe(v.literal('mso_mdoc'), v.description(`REQUIRED. A string that specifies the format of the requested Verifiable Credential.`)),
        claims: v.pipe(v.optional(v.pipe(v.array(m_dcql_claims_query_js_1.DcqlClaimsQuery.vMdoc), (0, u_dcql_js_1.vNonEmptyArray)())), v.description(`OPTIONAL. A non-empty array of objects as that specifies claims in the requested Credential.`)),
        meta: v.pipe(v.optional(v.object({
            doctype_value: v.pipe(v.optional(v.string()), v.description(`OPTIONAL. String that specifies an allowed value for the doctype of the requested Verifiable Credential.`)),
        })), v.description(`OPTIONAL. An object defining additional properties requested by the Verifier that apply to the metadata and validity data of the Credential.`)),
    });
    DcqlCredentialQuery.vSdJwtVc = v.object({
        ...vBase.entries,
        format: v.pipe(v.literal('vc+sd-jwt'), v.description(`REQUIRED. A string that specifies the format of the requested Verifiable Credential.`)),
        claims: v.pipe(v.optional(v.pipe(v.array(m_dcql_claims_query_js_1.DcqlClaimsQuery.vW3cSdJwtVc), (0, u_dcql_js_1.vNonEmptyArray)())), v.description(`OPTIONAL. A non-empty array of objects as that specifies claims in the requested Credential.`)),
        meta: v.pipe(v.optional(v.pipe(v.object({
            vct_values: v.optional(v.array(v.string())),
        }), v.description(`OPTIONAL. An array of strings that specifies allowed values for the type of the requested Verifiable Credential.`))), v.description(`OPTIONAL. An object defining additional properties requested by the Verifier that apply to the metadata and validity data of the Credential.`)),
    });
    DcqlCredentialQuery.vW3cVc = v.object({
        ...vBase.entries,
        format: v.picklist(['jwt_vc_json', 'jwt_vc_json-ld']),
        claims: v.optional(v.pipe(v.array(m_dcql_claims_query_js_1.DcqlClaimsQuery.vW3cSdJwtVc), (0, u_dcql_js_1.vNonEmptyArray)())),
    });
    DcqlCredentialQuery.vModel = v.variant('format', [DcqlCredentialQuery.vMdoc, DcqlCredentialQuery.vSdJwtVc, DcqlCredentialQuery.vW3cVc]);
    DcqlCredentialQuery.validate = (credentialQuery) => {
        claimSetIdsAreDefined(credentialQuery);
    };
})(DcqlCredentialQuery || (exports.DcqlCredentialQuery = DcqlCredentialQuery = {}));
// --- validations --- //
const claimSetIdsAreDefined = (credentialQuery) => {
    if (!credentialQuery.claim_sets)
        return;
    const claimIds = new Set(credentialQuery.claims?.map(claim => claim.id));
    const undefinedClaims = [];
    for (const claim_set of credentialQuery.claim_sets) {
        for (const claim_id of claim_set) {
            if (!claimIds.has(claim_id)) {
                undefinedClaims.push(claim_id);
            }
        }
    }
    if (undefinedClaims.length > 0) {
        throw new e_dcql_js_1.DcqlUndefinedClaimSetIdError({
            message: `Credential set contains undefined credential id${undefinedClaims.length === 0 ? '' : '`s'} '${undefinedClaims.join(', ')}'`,
        });
    }
};
//# sourceMappingURL=m-dcql-credential-query.js.map