"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DcqlQuery = void 0;
const v = __importStar(require("valibot"));
const e_dcql_js_1 = require("../dcql-error/e-dcql.js");
const run_dcql_query_js_1 = require("../dcql-query-result/run-dcql-query.js");
const u_dcql_js_1 = require("../u-dcql.js");
const m_dcql_credential_query_js_1 = require("./m-dcql-credential-query.js");
const m_dcql_credential_set_query_js_1 = require("./m-dcql-credential-set-query.js");
/**
 * The Digital Credentials Query Language (DCQL, pronounced [ˈdakl̩]) is a
 * JSON-encoded query language that allows the Verifier to request Verifiable
 * Presentations that match the query. The Verifier MAY encode constraints on the
 * combinations of credentials and claims that are requested. The Wallet evaluates
 * the query against the Verifiable Credentials it holds and returns Verifiable
 * Presentations matching the query.
 */
var DcqlQuery;
(function (DcqlQuery) {
    DcqlQuery.vModel = v.object({
        credentials: v.pipe(v.array(m_dcql_credential_query_js_1.DcqlCredentialQuery.vModel), (0, u_dcql_js_1.vNonEmptyArray)(), v.description(`REQUIRED. A non-empty array of Credential Queries that specify the requested Verifiable Credentials.`)),
        credential_sets: v.pipe(v.optional(v.pipe(v.array(m_dcql_credential_set_query_js_1.CredentialSetQuery.vModel), (0, u_dcql_js_1.vNonEmptyArray)())), v.description(`OPTIONAL. A non-empty array of credential set queries that specifies additional constraints on which of the requested Verifiable Credentials to return.`)),
    });
    DcqlQuery.validate = (dcqlQuery) => {
        validateUniqueCredentialQueryIds(dcqlQuery);
        validateCredentialSets(dcqlQuery);
        dcqlQuery.credentials.forEach(m_dcql_credential_query_js_1.DcqlCredentialQuery.validate);
    };
    DcqlQuery.query = (dcqlQuery, credentials) => {
        return (0, run_dcql_query_js_1.runDcqlQuery)(dcqlQuery, { credentials, presentation: false });
    };
    DcqlQuery.parse = (input) => {
        return v.parse(DcqlQuery.vModel, input);
    };
})(DcqlQuery || (exports.DcqlQuery = DcqlQuery = {}));
// --- validations --- //
const validateUniqueCredentialQueryIds = (query) => {
    const ids = query.credentials.map(c => c.id);
    const duplicates = ids.filter((id, index) => ids.indexOf(id) !== index);
    if (duplicates.length > 0) {
        throw new e_dcql_js_1.DcqlNonUniqueCredentialQueryIdsError({
            message: `Duplicate credential query ids found: ${duplicates.join(', ')}`,
        });
    }
};
const validateCredentialSets = (query) => {
    if (!query.credential_sets)
        return;
    const credentialQueryIds = new Set(query.credentials.map(c => c.id));
    const undefinedCredentialQueryIds = [];
    for (const credential_set of query.credential_sets) {
        for (const credentialSetOption of credential_set.options) {
            for (const credentialQueryId of credentialSetOption) {
                if (!credentialQueryIds.has(credentialQueryId)) {
                    undefinedCredentialQueryIds.push(credentialQueryId);
                }
            }
        }
    }
    if (undefinedCredentialQueryIds.length > 0) {
        throw new e_dcql_js_1.DcqlCredentialSetError({
            message: `Credential set contains undefined credential id${undefinedCredentialQueryIds.length === 1 ? '' : '`s'} '${undefinedCredentialQueryIds.join(', ')}'`,
        });
    }
};
//# sourceMappingURL=m-dcql-query.js.map